=========================
django-codenerix-payments
=========================

Codenerix Payments is a module that enables `CODENERIX.com <http://www.codenerix.com/>`_ to manage payments and let clients to pay online.

.. image:: http://www.centrologic.com/wp-content/uploads/2017/01/logo-codenerix.png
    :target: http://www.codenerix.com
    :alt: Try our demo with Centrologic Cloud

********
Features
********

* `Paypal <https://www.paypal.com/>`_
* `Redsys <http://www.redsys.es/en/>`_

****
Demo
****

Comin soon...

**********
Quickstart
**********

1. Install this package::

    For python 2: sudo pip2 install django-codenerix-payments
    For python 3: sudo pip3 install django-codenerix-payments

2. Add "codenerix_payments" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'codenerix_payments',
    ]

3. Since Codenerix Payments is a library, you only need to import its parts into your project and use them.

*************
Documentation
*************

Coming soon... do you help us? `Centrologic <http://www.centrologic.com/>`_

******************
Commercial support
******************

This project is backed by `Centrologic <http://www.centrologic.com/>`_. You can discover more in `CODENERIX.com <http://www.codenerix.com/>`_.
If you need help implementing or hosting django-codenerix-payments, please contact us:
http://www.centrologic.com/contacto/

.. image:: http://www.centrologic.com/wp-content/uploads/2015/09/logo-centrologic.png
    :target: http://www.centrologic.com
    :alt: Centrologic is supported mainly by Centrologic Computational Logistic Center
